# VintaSend Celery

Celery adapter base implementation for VintaSend. 

This package doesn't implement an actual adapter, but it helps you to make an existing adapter to run from a Celery worker.


## Installation

To install VintaSend Celery you need to run the following command:

```shell
pip install vinstasend vintasend-celery
```


## Quick start

To use VintaSend Celery you need to manually register your tasks